package Events;

import commandSystem.Direction;

public interface Event {

	/**
	 * Gets the EventType associated with the event
	 * 
	 * @return the EventType of the event.
	 */
	public EventType getType();

	/*
	 * 
	 * 
	 * CallFromFloorEvent methods
	 * 
	 * 
	 */
	
	/**
	 * Gets the direction of a floor call.
	 * 
	 * @return the direction of the floor call, unconcerned extending classes return
	 *         NONE.
	 */
	public Direction getRequestedDirection();

	/**
	 * Gets the source floor of a floor call.
	 * 
	 * @return the floor the event was called from, unconcerned extending classes
	 *         return -1.
	 */
	public int getIncomingCallFloor();

	/*
	 * 
	 * 
	 * CallFromElevatorEvent methods
	 * 
	 * 
	 */

	/**
	 * Gets the requested floor of an inside-elevator call.
	 * 
	 * @return the requested floor, unconcerned extending classes return -1.
	 */
	public int getRequestedFloor();

	/*
	 * 
	 * 
	 * ReachedFloorEvent methods
	 * 
	 * 
	 */

	/**
	 * Gets the index of the floor just reached.
	 * 
	 * @return the floor the elevator just reached, unconcerned extending classes
	 *         return -1.
	 */
	public int getCurrentFloor();

	/**
	 * Gets the direction the elevator reached the last floor from.
	 * 
	 * @return the direction of the elevator. Unconcerned extending classes return
	 *         NONE.
	 */
	public Direction getCurrentDirection();
}
